#!/usr/bin/python3
"""
// © University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road,
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Nikolay Stanchev
//      Created Date :          25-06-2018
//      Created for Project :   FLAME
"""

from json import loads
from clmcservice.models import ServiceFunctionEndpoint


def validate_sfendpoint_body(body):
    """
    Validates the request body used to create an endpoint configuration resource in the database.

    :param body: the request body to validate

    :return the validated configuration dictionary object

    :raise AssertionError: if the body is not a valid configuration
    """

    try:
        body = loads(body)
    except Exception:
        raise AssertionError("Configuration must be a JSON object.")

    assert len(body) == len(ServiceFunctionEndpoint.__table__.columns), "Endpoint configuration mustn't contain a different number of attributes than the number of required ones."

    # validate that all required attributes are given in the body
    for attribute in ServiceFunctionEndpoint.__table__.columns:
        assert attribute.name in body, "Required attribute not found in the request content."

    return body
